@@ -270,14 +270,19 @@ function generateModuleByName(moduleName,defines,sideName){
 function generateFramework(defines,param){
     initPathEnv(defines);
     generateFrameworkDirectories();
-    copyFrameworkFiles();
+    //copyFrameworkFiles();
     copyReleaseFrameworkFiles();
 }
 function initProjectEnv(defines){
     initPathEnv(defines);
 }
 
+function generateCommon(sideName){
+    copyFrameworkFiles();
+}
+
 exports.generateFramework = generateFramework;
+exports.generateCommon = generateCommon;
 exports.generateModuleByName = generateModuleByName;
 exports.initEnv = initPathEnv;
 
