@@ -11,11 +11,11 @@ var webpackBaseConfig = require("./webpack.config.base.js");
 //var cfg = Object.assign(webpackBaseConfig, {
 //    devtool: "cheap-module-eval-source-map"
 //});
-
+const pxtorem = require('postcss-pxtorem');
 
 process.env.NODE_ENV = 'production';
 
-var projectModule = 'admin/product';
+var projectModule = 'client/product';
 
 var config = {
 
@@ -32,23 +32,37 @@ var config = {
         publicPath: '/'+projectModule+'/',//html引用路径
         filename: '[name].js' // 注意我们使用了变量
     },
-
+    devtool: false,
+    //postcss:[pxtorem({
+    //    rootValue: 100,
+    //    propWhiteList: [],
+    //})],
     babel: {
         //presets: ['es2015', 'stage-0', 'react'],
         presets: ['es2015', 'react', 'stage-1'],
-        plugins: [['import', {
-            libraryName: 'antd',
-            style: 'css'
-        }]]
+        plugins: ['transform-runtime',['import', [{
+            "libraryName": 'antd',
+            "style": 'css'
+        },{
+            "libraryName": 'antd-mobile',
+            "style": 'css'
+        },{
+            libraryName: 'material-ui',
+            libraryDirectory:'components',
+            camel2DashComponentName:false,
+        }]
+        ]]
     },
     //插件项
-    plugins:[
-        new webpack.DefinePlugin({
-            'process.env':{
-                'NODE_ENV':'production'
-            }
-        }),
 
+    plugins:[
+         /*
+         new webpack.DefinePlugin({
+         'process.env':{
+         'NODE_ENV': JSON.stringify('production')
+         }
+         }),
+         */
         //new HtmlWebpackPlugin({
         //    template:'./index.html',    //html模板路径
         //    inject:true,    //允许插件修改哪些内容，包括head与body
@@ -59,6 +73,9 @@ var config = {
         //    minChunks:Infinity
         //}),
         new webpack.optimize.UglifyJsPlugin({
+            output: {
+                comments: false,  // remove all comments
+            },
              compress: {
                  warnings: false
              }
@@ -73,4 +90,4 @@ var config = {
 
 console.log("ENV:" + process.env.NODE_ENV);
 
-module.exports = config;
\ No newline at end of file
+module.exports = config;
