@@ -5,13 +5,17 @@ import java.util.List;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Controller;
 import org.springframework.web.bind.annotation.*;
-import org.springframework.web.servlet.ModelAndView;
+//import org.springframework.web.servlet.ModelAndView;
 
 import com.simple.core.base.user.entity.*;
 import com.simple.core.base.user.service.*;
 
+import com.simple.server.bz.entity.*;
+import com.simple.server.bz.service.*;
+
 import <%=data.packageName%>.entity.*;
 import <%=data.packageName%>.service.*;
+import <%=data.packageName%>.dao.*;
 
 
 //import io.swagger.annotations.ApiImplicitParam;
@@ -23,6 +27,9 @@ public class <%=data.moduleName%>Controller {
 	@Autowired
 	<%=data.moduleName%>Service service;
 
+	@Autowired
+    <%=data.moduleName%>QueryDao queryDao;
+
   <% for (var field in data.moduleDefine){
                 var fieldDef  = data.moduleDefine[field];
                 var fieldName = fieldDef.dName;
@@ -61,17 +68,18 @@ public class <%=data.moduleName%>Controller {
 
     }
 
+
     @ResponseBody
-	@RequestMapping(value = "/", method = RequestMethod.POST)
-	public <%=data.moduleName%> save(@RequestBody <%=data.moduleName%> item) {
-		System.out.println("input device params:" + item.toString());
-		<%=data.moduleName%> result = service.save(item);
-		System.out.println("output device result data:" + result.toString());
-		return result;
-	}
+    @RequestMapping(value = "/queryByName", method = RequestMethod.GET)
+    public List<<%=data.moduleName%>> findByName(@RequestParam("name") String name ) {
+           	System.out.println("input param Name:" + name);
+            return queryDao.findByName(name);
+
+    }
+
     @ResponseBody
 	@RequestMapping(value = "/save", method = RequestMethod.POST)
-	public <%=data.moduleName%> save2(@RequestBody <%=data.moduleName%> item) {
+	public Long save2(@RequestBody <%=data.moduleName%> item) {
 		 <% for (var field in data.moduleDefine){
                                    var fieldDef  = data.moduleDefine[field];
                                    var fieldName = fieldDef.dName;
@@ -83,55 +91,22 @@ public class <%=data.moduleName%>Controller {
                                    var fieldNameUpper = data.firstUpper(field);
                                    var idType = data.moduleDefine['id'].type;
                                    if(refer.module==='user'){%>
-                                   User currentUser = userService.obtainCurrentUser();
-                                   if(null == currentUser){throw new RuntimeException("User not Login!"); };
-                                   item.set<%=fieldNameUpper%>(currentUser);
-
-
-                                   <%continue;}%>
-
-                   <%=idType%> <%=field%>Id =item.get<%=fieldNameUpper%>().getId();
-                   if (<%=field%>Id > 0){
-                   	  <%=clsName%> <%=field%>Obj = <%=refer.module%>Service.findById(<%=field%>Id);
-                      item.set<%=fieldNameUpper%>(<%=field%>Obj);
-                   }
-         <%}else if(refer&&(refer.map==="OneToMany")){
-         	  var clsName = data.firstUpper(refer.module);
-        	  var fieldNameUpper = data.firstUpper(field);
-        	  var idType = data.moduleDefine['id'].type;
-         %>
-
-
-    	           for(int i=0; i < item.get<%=fieldNameUpper%>List().size();i++){
-    	        	   <%=clsName%> oldOne = item.get<%=fieldNameUpper%>List().get(i);
-    	        	   if (oldOne.getId() == null){
-    	        		   item.get<%=fieldNameUpper%>List().remove(i);
-    	        		    <%=clsName%> newOne = <%=refer.module%>Service.save(oldOne);
-    	        		   item.get<%=fieldNameUpper%>List().add(newOne);
-    	        	   }
-    	           }
-
-         <%}}%>
+         User currentUser = userService.obtainCurrentUser();
+         if(null == currentUser){throw new RuntimeException("User not Login!"); };
+         item.set<%=fieldNameUpper%>(currentUser);
+                                   <%}}}%>
 
 		System.out.println("input device params:" + item.toString());
 		<%=data.moduleName%> result = service.save(item);
 		System.out.println("output device result data:" + result.toString());
-		return result;
+		return result.getId();
 	}
 
 
-    @ResponseBody
- 	@RequestMapping(value = "/{id}", method = RequestMethod.PUT)
- 	public <%=data.moduleName%> update(@PathVariable Long id, @RequestBody <%=data.moduleName%> item) {
- 		System.out.println("input device params:" + item.toString());
- 		<%=data.moduleName%> result = service.save(item);
- 		System.out.println("output device result data:" + result.toString());
- 		return result;
- 	}
 
  	@ResponseBody
-     	@RequestMapping(value = "/update/{id}", method = RequestMethod.POST)
-     	public <%=data.moduleName%> updateSave(@PathVariable Long id, @RequestBody <%=data.moduleName%> item) {
+    @RequestMapping(value = "/update/{id}", method = RequestMethod.POST)
+    public Long updateSave(@PathVariable Long id, @RequestBody <%=data.moduleName%> item) {
      	   <% for (var field in data.moduleDefine){
                            var fieldDef  = data.moduleDefine[field];
                            var fieldName = fieldDef.dName;
@@ -139,41 +114,21 @@ public class <%=data.moduleName%>Controller {
 
                            var refer = fieldDef.refer;
                            if (refer&&(refer.map==="ManyToOne")) {
+
                            var clsName = data.firstUpper(refer.module);
                            var fieldNameUpper = data.firstUpper(field);
                            var idType = data.moduleDefine['id'].type;
-           %>
-           <%=idType%> <%=field%>Id =item.get<%=fieldNameUpper%>().getId();
-           if (<%=field%>Id > 0){
-           	  <%=clsName%> <%=field%>Obj = <%=refer.module%>Service.findById(<%=field%>Id);
-              item.set<%=fieldNameUpper%>(<%=field%>Obj);
-           }
+                           if(refer.module==='user'){%>
+         User currentUser = userService.obtainCurrentUser();
+         if(null == currentUser){throw new RuntimeException("User not Login!"); };
+         item.set<%=fieldNameUpper%>(currentUser);
+                                             <%}}}%>
 
-             <%}else if (refer&&(refer.map==="OneToMany")){
-            	  var clsName = data.firstUpper(refer.module);
-                  var fieldNameUpper = data.firstUpper(field);
-                  var idType = data.moduleDefine['id'].type;
-              %>
-
-
-                	           for(int i=0; i < item.get<%=fieldNameUpper%>List().size();i++){
-                	        	   <%=clsName%> oldOne = item.get<%=fieldNameUpper%>List().get(i);
-                	        	   if (oldOne.getId() == null){
-                	        		   item.get<%=fieldNameUpper%>List().remove(i);
-                	        		    <%=clsName%> newOne = <%=refer.module%>Service.save(oldOne);
-                	        		   item.get<%=fieldNameUpper%>List().add(newOne);
-                	        	   }
-                	           }
-
-           <%}}%>
-
-
-
-     		System.out.println("input device params:" + item.toString());
-     		<%=data.moduleName%> result = service.save(item);
-     		System.out.println("output device result data:" + result.toString());
-     		return result;
-     	}
+     	 System.out.println("input device params:" + item.toString());
+     	 <%=data.moduleName%> result = service.save(item);
+     	 System.out.println("output device result data:" + result.toString());
+     	 return result.getId();
+    }
 
 
 
